PCB Environment: Data Fields - Variables

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all variables with links to the structures/unions they belong to:

### - n -

- N : CloneEnv, math::Moments
- name : dsn::Image, dsn::Layer, dsn::Net, dsn::Padstack, dsn::PCB, dsn::Pin, dsn::Placement
- net : dsn::Pin, UIActions
- Nets : Palette
- nets : dsn::Data, PCBItemSets, PCBoard
- None : UserAgent
- NumDisconnected : RouterResult
- NumLevels : Logger
- NumVias : RouterResult